@@ -1,5 +1,5 @@
-from collections import Iterable
-from .._compat import string_types
+import collections
+
 
 _operator_name_to_sign_str = {
     "eq": '=',
@@ -10,9 +10,7 @@ _operator_name_to_sign_str = {
     "ne": '!='}
 
 
-
-
-class FieldFilter(object):
+class FieldFilter:
 
     def __init__(self, field, operator_name, value):
         super(FieldFilter, self).__init__()
@@ -21,11 +19,14 @@ class FieldFilter(object):
         self.value = value
 
     def _translate(self, value, system):
-        if isinstance(self.value, Iterable) and not isinstance(self.value, string_types):
-            value = "({})".format(",".join(str(self._translate_single_value(val, system)) for val in self.value))
-        else:
-            value = self._translate_single_value(value, system)
-        return value
+        if self.operator_name in ("allof", "anyof", "noneof"):
+            if (not isinstance(value, collections.abc.Iterable) or isinstance(value, (str, bytes)) or
+                    not all(isinstance(element, str) for element in value)):
+                raise ValueError("Expected an iterable of strings, but got {}".format(repr(value)))
+            return ",".join(value)
+        if isinstance(self.value, collections.abc.Iterable) and not isinstance(self.value, (str, bytes)):
+            return "({})".format(",".join(str(self._translate_single_value(val, system)) for val in self.value))
+        return self._translate_single_value(value, system)
 
     def add_to_url(self, urlobj, system):
         value = self._translate(self.value, system)
